@@ -1368,7 +1368,7 @@ plot.crs <- function(x,
 
       if(plot.behavior!="data") {
 
-        if(!is.null(object$num.z)||(object$num.x>1)) par(mfrow=dim.plot(NCOL(object$xz)))
+        if(!is.null(object$num.z)||(object$num.x>1)) par(mfrow=n2mfrow(NCOL(object$xz)))
 
         for(i in 1:NCOL(object$xz)) {
 
@@ -1744,7 +1744,7 @@ plot.crs <- function(x,
 
       if(plot.behavior!="data") {
 
-        if(!is.null(object$num.z)||(object$num.x>1)) par(mfrow=dim.plot(NCOL(object$xz)))
+        if(!is.null(object$num.z)||(object$num.x>1)) par(mfrow=n2mfrow(NCOL(object$xz)))
 
         for(i in 1:NCOL(object$xz)) {
 
